@@ -263,8 +263,10 @@ class R3sponse(object):
 					try: value = float(value)
 					except: a=1
 				else:
-					try: value = int(value)
-					except: a=1
+					try: value = ast.literal_eval(value)
+					except:
+						try: value = int(value)
+						except: a=1
 			response[key] = value
 		return response
 	def response(self, response={
@@ -357,6 +359,7 @@ class R3sponse(object):
 			else:
 				return json.dumps(self.dict(), indent=4)
 		def json(self,):
+			return json.dumps(self.dict(serializable=True), indent=4)
 			return self.dict(serializable=True) # seems to work for django.
 			return self.dict(serializable=True)
 			return json.dumps(self.dict(serializable=True), indent=4)
